Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1253)

Unified Diff: pkg/analysis_server/lib/src/services/index/local_index.dart

Issue 1087483006: Rename two more classes to prepare for the public API (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/lib/src/services/index/local_index.dart
diff --git a/pkg/analysis_server/lib/src/services/index/local_index.dart b/pkg/analysis_server/lib/src/services/index/local_index.dart
index e9deeda04475f6a6e9d1818f7c6fc6617366e4d5..a11db6d90d51a5d5cd2fabef5fe79fa452767e0f 100644
--- a/pkg/analysis_server/lib/src/services/index/local_index.dart
+++ b/pkg/analysis_server/lib/src/services/index/local_index.dart
@@ -44,15 +44,15 @@ class LocalIndex extends Index {
/**
* Returns a `Future<List<Location>>` that completes with the list of
* [Location]s of the given [relationship] with the given [element].
*
* For example, if the [element] represents a function and the [relationship]
* is the `is-invoked-by` relationship, then the locations will be all of the
* places where the function is invoked.
*/
@override
- Future<List<Location>> getRelationships(
- Element element, Relationship relationship) {
+ Future<List<LocationImpl>> getRelationships(
+ Element element, RelationshipImpl relationship) {
return _store.getRelationships(element, relationship);
}
@@ -44,15 +44,15 @@ class LocalIndex extends Index {
/**
* Returns a `Future<List<Location>>` that completes with the list of
- * [Location]s of the given [relationship] with the given [element].
+ * [LocationImpl]s of the given [relationship] with the given [element].
*
* For example, if the [element] represents a function and the [relationship]

Powered by Google App Engine
This is Rietveld 408576698